@@ -100,7 +100,7 @@ func main() {
 // gopoghVersion returns gopogh stable version in semver format.
 func gopoghVersion(ctx context.Context, owner, repo string) (stable string, err error) {
 	// get Kubernetes versions from GitHub Releases
-	stable, _, err = update.GHReleases(ctx, owner, repo)
+	stable, _, _, err = update.GHReleases(ctx, owner, repo)
 	if err != nil || !semver.IsValid(stable) {
 		return "", err
 	}
